/**
 * @file
 * Sheephole helper behaviors.
 */
(function ($, Drupal, drupalSettings) {

	'use strict';

	Drupal.behaviors.sheepholeHelper = {
		attach: function (context, settings) {
			isSheepholeOnline(function() {
				addButtons(context, settings);
			});
		}
	};

	function isSheepholeOnline(callback) {
		$.get(drupalSettings.path.baseUrl + "sheephole-helper/is-online", function(data) {
			if ((typeof data['status'] !== 'undefined') && data['status'] === 'ok') {
				callback();
			}
		})
		.fail(function() {
		});
	}

	function installModule(machineName) {
		$.post(drupalSettings.path.baseUrl + "sheephole-helper/install-module", { machine_name: machineName }, function(data) {
		})
		.fail(function() {
		});
	}

	function addButtons(context, settings) {
		setInterval(function() {
			once('has-sheephole-button', '.pb-actions', context).forEach(function (element) {
				var buttonText = $(element).text();
				if (buttonText.startsWith(Drupal.t('Install')) || buttonText.startsWith(Drupal.t('View Commands'))) {
					var btn = $('<button>').addClass(['pb__action_button', 'sheephole_helper_button']).attr('title', Drupal.t('Install with Sheephole'));
					$(element).before(btn);
					btn.on('click', function() {
						var id = $(element).parent().parent().find('.pb-project__link').attr('id');
						if (id) {
							var ary = id.match(/(.*)_title$/);
							var machineName = !(typeof ary[1] === 'undefined') ? ary[1] : null;
							if (machineName) {
								installModule(machineName);
							}
						}
					});
				}
			});
		}, 2000);
	}

	// This is the original, more elegant version.
	// However, it only works on the first page of results:
	// https://www.drupal.org/project/project_browser/issues/3508144
	function addButtonsHOLD(context, settings) {
		var targetNode = document.getElementById("project-browser");
		if (Drupal.behaviors.sheepholeHelper.observing || Drupal.behaviors.sheepholeHelper.adding || !targetNode) {
			return;
		}
		Drupal.behaviors.sheepholeHelper.observing = true;

		const config = { childList: true, subtree: true };
		const callback = (mutationList, observer) => {
			for (const mutation of mutationList) {
				if (!Drupal.behaviors.sheepholeHelper.adding && mutation.type === "childList") {
					$('.pb-actions').each(function() {
						var buttonText = $(this).text();
						if (buttonText.startsWith(Drupal.t('Install')) || buttonText.startsWith(Drupal.t('View Commands'))) {
							Drupal.behaviors.sheepholeHelper.adding = true;
							var btn = $('<button>').addClass(['pb__action_button', 'sheephole_helper_button']).attr('title', Drupal.t('Install with Sheephole'));
							$(this).before(btn);
							btn.on('click', function() {
								var id = $(this).parent().parent().find('.pb-project__link').attr('id');
								if (id) {
									var ary = id.match(/(.*)_title$/);
									var machineName = !(typeof ary[1] === 'undefined') ? ary[1] : null;
									if (machineName) {
										installModule(machineName);
									}
								}
							});
						}
					});
				}
			}
		};
		const observer = new MutationObserver(callback);
		observer.observe(targetNode, config);
	}
})(jQuery, Drupal, drupalSettings);
