<?php

declare(strict_types=1);

namespace Drupal\sheephole_helper\Controller;

use Drupal\Core\Controller\ControllerBase;
use GuzzleHttp\Client;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Returns responses for Sheephole helper routes.
 */
final class SheepholeHelperController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly Client $httpClient,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('http_client'),
    );
  }

  /**
   * Is the Java application open?
   */
  public function isOnline(Request $request) {
    if (!in_array($request->getClientIp(), ['127.0.0.1', 'localhost'])) {
      $response = new Response();
      $response->setStatusCode(Response::HTTP_INTERNAL_SERVER_ERROR, '500 Service unavailable.');
      return $response;
    }

    $response = NULL;

    try {
      $response = $this->httpClient->get('http://127.0.0.1:41295/hurdy', [
        'timeout' => 10,
      ]);
    }
    catch (\Exception $e) {
    }

    if ($response && ('' . $response->getBody() == 'gurdy')) {
      $json = [
        'status' => 'ok',
      ];
    }
    else {
      $json = [
        'status' => 'no_connection',
      ];
    }

    return new JsonResponse($json);
  }

  /**
   * Install a module.
   */
  public function installModule(Request $request) {
    $machineName = $request->get('machine_name');

    if (!$machineName) {
      $response = new Response();
      $response->setStatusCode(Response::HTTP_INTERNAL_SERVER_ERROR, '500 Service unavailable.');
      return $response;
    }

    $response = NULL;

    try {
      $response = $this->httpClient->post('http://127.0.0.1:41295/install-module', [
        'timeout' => 10,
        'form_params' => [
          'machine_name' => $machineName,
        ],
      ]);
    }
    catch (\Exception $e) {
    }

    if ($response && ('' . $response->getBody() == 'bombarde')) {
      $json = [
        'status' => 'ok',
      ];
    }
    else {
      $json = [
        'status' => 'no_connection',
      ];
    }

    return new JsonResponse($json);
  }

}
